@@ -1,9 +1,9 @@
 
 ### MODULES
-
+import re
 import urllib.request
 import dateparser, copy
-from bs4 import BeautifulSoup as Soup
+from bs4 import BeautifulSoup as Soup, ResultSet
 from dateutil.parser import parse
 
 ### METHODS
@@ -37,6 +37,7 @@ class GoogleNews:
         self.__texts = []
         self.__links = []
         self.__results = []
+        self.__totalcount = 0
         self.user_agent = 'Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:64.0) Gecko/20100101 Firefox/64.0'
         self.headers = {'User-Agent': self.user_agent}
         self.__lang = lang
@@ -85,6 +86,76 @@ class GoogleNews:
             self.__key = urllib.request.quote(self.__key.encode(self.__encode))
         self.get_page()
 
+    def build_response(self):
+        self.req = urllib.request.Request(self.url, headers=self.headers)
+        self.response = urllib.request.urlopen(self.req)
+        self.page = self.response.read()
+        self.content = Soup(self.page, "html.parser")
+        stats = self.content.find_all("div", id="result-stats")
+        if stats and isinstance(stats, ResultSet):
+            stats = re.search(r'\d+', stats[0].text)
+            self.__totalcount = int(stats.group())
+        else:
+            #TODO might want to add output for user to know no data was found
+            return
+        result = self.content.find_all("div", id="search")[0].find_all("g-card")
+        return result
+
+    def page_at(self, page=1):
+        """
+        Retrieves a specific page from google.com in the news sections into __results.
+
+        Parameter:
+        page = number of the page to be retrieved
+        """
+        results = []
+        try:
+            if self.__start != "" and self.__end != "":
+                self.url = "https://www.google.com/search?q={}&lr=lang_{}&biw=1920&bih=976&source=lnt&&tbs=lr:lang_1{},cdr:1,cd_min:{},cd_max:{},sbd:1&tbm=nws&start={}".format(self.__key,self.__lang,self.__lang,self.__start,self.__end,(10 * (page - 1)))
+            elif self.__period != "":
+                self.url = "https://www.google.com/search?q={}&lr=lang_{}&biw=1920&bih=976&source=lnt&&tbs=lr:lang_1{},qdr:{},,sbd:1&tbm=nws&start={}".format(self.__key,self.__lang,self.__lang,self.__period,(10 * (page - 1))) 
+            else:
+                self.url = "https://www.google.com/search?q={}&lr=lang_{}&biw=1920&bih=976&source=lnt&&tbs=lr:lang_1{},sbd:1&tbm=nws&start={}".format(self.__key,self.__lang,self.__lang,(10 * (page - 1))) 
+        except AttributeError:
+            raise AttributeError("You need to run a search() before using get_page().")
+        try:
+            result = self.build_response()
+            for item in result:
+                try:
+                    tmp_text = item.find("div", {"role" : "heading"}).text.replace("\n","")
+                except Exception:
+                    tmp_text = ''
+                try:
+                    tmp_link = item.find("a").get("href")
+                except Exception:
+                    tmp_link = ''
+                try:
+                    tmp_media = item.findAll("g-img")[1].parent.text
+                except Exception:
+                    tmp_media = ''
+                try:
+                    tmp_date = item.find("div", {"role" : "heading"}).next_sibling.findNext('div').findNext('div').text
+                    tmp_date,tmp_datetime=lexical_date_parser(tmp_date)
+                except Exception:
+                    tmp_date = ''
+                    tmp_datetime=None
+                try:
+                    tmp_desc = item.find("div", {"role" : "heading"}).next_sibling.findNext('div').text.replace("\n","")
+                except Exception:
+                    tmp_desc = ''
+                try:
+                    tmp_img = item.findAll("g-img")[0].find("img").get("src")
+                except Exception:
+                    tmp_img = ''
+                self.__texts.append(tmp_text)
+                self.__links.append(tmp_link)
+                results.append({'title': tmp_text, 'media': tmp_media,'date': tmp_date,'datetime':tmp_datetime,'desc': tmp_desc, 'link': tmp_link,'img': tmp_img})
+            self.response.close()
+        except Exception as e_parser:
+            print(e_parser)
+            pass
+        return results
+
     def get_page(self, page=1):
         """
         Retrieves a specific page from google.com in the news sections into __results.
@@ -94,19 +165,15 @@ class GoogleNews:
         """
         try:
             if self.__start != "" and self.__end != "":
-                self.url = "https://www.google.com/search?q={}&lr=lang_{}&tbs=lr:lang_1{},cdr:1,cd_min:{},cd_max:{}&tbm=nws&start={}".format(self.__key,self.__lang,self.__lang,self.__start,self.__end,(10 * (page - 1)))
+                self.url = "https://www.google.com/search?q={}&lr=lang_{}&biw=1920&bih=976&source=lnt&&tbs=lr:lang_1{},cdr:1,cd_min:{},cd_max:{},sbd:1&tbm=nws&start={}".format(self.__key,self.__lang,self.__lang,self.__start,self.__end,(10 * (page - 1)))
             elif self.__period != "":
-                self.url = "https://www.google.com/search?q={}&lr=lang_{}&tbs=lr:lang_1{},qdr:{},&tbm=nws&start={}".format(self.__key,self.__lang,self.__lang,self.__period,(10 * (page - 1))) 
+                self.url = "https://www.google.com/search?q={}&lr=lang_{}&biw=1920&bih=976&source=lnt&&tbs=lr:lang_1{},qdr:{},,sbd:1&tbm=nws&start={}".format(self.__key,self.__lang,self.__lang,self.__period,(10 * (page - 1))) 
             else:
-                self.url = "https://www.google.com/search?q={}&lr=lang_{}&tbs=lr:lang_1{}&tbm=nws&start={}".format(self.__key,self.__lang,self.__lang,(10 * (page - 1))) 
+                self.url = "https://www.google.com/search?q={}&lr=lang_{}&biw=1920&bih=976&source=lnt&&tbs=lr:lang_1{},sbd:1&tbm=nws&start={}".format(self.__key,self.__lang,self.__lang,(10 * (page - 1))) 
         except AttributeError:
             raise AttributeError("You need to run a search() before using get_page().")
         try:
-            self.req = urllib.request.Request(self.url, headers=self.headers)
-            self.response = urllib.request.urlopen(self.req)
-            self.page = self.response.read()
-            self.content = Soup(self.page, "html.parser")
-            result = self.content.find_all("div", id="search")[0].find_all("g-card")
+            result = self.build_response()
             for item in result:
                 try:
                     tmp_text = item.find("div", {"role" : "heading"}).text.replace("\n","")
@@ -138,7 +205,8 @@ class GoogleNews:
                 self.__links.append(tmp_link)
                 self.__results.append({'title': tmp_text, 'media': tmp_media,'date': tmp_date,'datetime':tmp_datetime,'desc': tmp_desc, 'link': tmp_link,'img': tmp_img})
             self.response.close()
-        except Exception:
+        except Exception as e_parser:
+            print(e_parser)
             pass
 
     def getpage(self, page=1):
@@ -220,6 +288,9 @@ class GoogleNews:
             print(e_parser)
             pass
 
+    def total_count(self):
+        return self.__totalcount
+
     def result(self,sort=False):
         """Don't remove this, will affect old version user when upgrade"""
         return self.results(sort)
@@ -252,3 +323,4 @@ class GoogleNews:
         self.__texts = []
         self.__links = []
         self.__results = []
+        self.__totalcount = 0
